@@ -174,6 +174,9 @@ def fusion2CombinFL(options):
     fusionTH['usage']=(fusionTH.end-fusionTH.start+1)/fusionTH.readLen
     fusionTH=fusionTH.loc[(fusionTH.copyNum>1.2) &(fusionTH.usage>0.5)]
     consFL_all_pass=consFL_all.loc[consFL_all.index.isin(set(consFL_all.index)-set(fusionTH['ID']))].copy()
+    if consFL_all_pass.shape[0]==0:
+        return
+
     tabixfile = pysam.TabixFile(gtfFile)
 
     if len(options)<=4: # no stranded
@@ -204,4 +207,4 @@ def fusion2CombinFL(options):
            'exonNum_second', 'exon_start_second', 'exon_end_second',
            'exon_leftSeq_second', 'exon_rightSeq_second', 'strand_second','geneName_second']]
            
-    consFL_out.to_csv(outPrefix+'result_fusion2.txt',sep='\t')
\ No newline at end of file
+    consFL_out.to_csv(outPrefix+'result_fusion2.txt',sep='\t')
