@@ -24,6 +24,7 @@ Command:
     anno           Annotate full-length circRNA.
     geneExp        Quantify gene expression to evaluate linear RNA residual
     var            Calling variants in circRNA.
+    partial        Count partial circRNA.
 '''
 
 def main():
@@ -59,8 +60,11 @@ def main():
     elif sys.argv[1] == 'var':
         import circfull.var as var
         var.var(docopt(var.__doc__, version=__version__))
+    elif sys.argv[1] == 'partial':
+        import circfull.partial as partial
+        partial.partial(docopt(partial.__doc__, version=__version__))
     else:
         sys.exit(helpInfo)
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
